Learn R Programming

UScancer (version 0.1-2)

dplookup:

Census demographics profile lookup table

Description

A lookup table for US census demographic profile data element to its full name. Only contains the codes for sex and age groups.

Usage

data(dplookup)

Arguments

Format

A data.frame object with 39 rows with the following 2 variables.
code
Demographic profile data element code
desc
A simplified description of the code. i.e. Male ages 5 to 9 is M5_9

Examples

Run this code
data(dplookup)

Run the code above in your browser using DataLab