Lookup table for 5-digit FIPS codes to state and county name.
Usage
data(fipslookup)
Arguments
Format
A data.frame object with 3227 rows and the following 2 variables.
state
State name
county
County name
Row names are the 5-digit FIPS code (state+county). State FIPS codes with only 1 digit are appended by a leading 0.
Original file taken from http://www.schooldata.com/pdfs/US_FIPS_Codes.xls with updates done manually. New counties (as of 2010) were added, along with FIPS codes for Hawaii, Alaska, and Puerto Rico.
Details
This is meant to be used with the readSEER function to be passed in as the fips argument.