siteLookup: Converts a name description to ICD matching pattern
Description
Given a cancer name (one from listCancers), a regular expression pattern is returned to match all ICD-09 site codes that are associated with that cancer name. This regex expression can be passed to readSEER as the site argument. Alternatively, this function is called internally by readSEER if only a cancer name is given.
Usage
siteLookup(cancer)
listCancers()
Arguments
cancer
Character string of a cancer name. Accepted names listed by listCancers.
Value
siteLookup returns a regular pattern expression used to match ICD-09 codes.
listCancers returns a vector of accepted cancer names.